@@ -2,10 +2,12 @@ tcprod <-
 function(X,Y=NULL){
   
   if(is.null(X) & is.null(Y)){
-    Z=0
+    Z <- 0
   } else if(is.null(Y)) {
-    Z=tcrossprod(X)
-  } else{Z=tcrossprod(X,Y)}
+    Z <- tcrossprod(X)
+  } else {
+    Z <- tcrossprod(X,Y)
+  }
   Z
   
 }
